diff --git a/codecs/Makefile b/codecs/Makefile
index 6ef08da..7c5ae96 100644
--- a/codecs/Makefile
+++ b/codecs/Makefile
@@ -50,7 +50,7 @@ $(LIBILBC):
 	@$(MAKE) -C ilbc all _ASTCFLAGS="$(filter-out -Wmissing-prototypes -Wmissing-declarations -Wshadow,$(_ASTCFLAGS)) $(AST_NO_STRICT_OVERFLOW)"
 
 
-$(if $(filter codec_ilbc,$(EMBEDDED_MODS)),modules.link,codec_ilbc.so): $(LIBILBC)
+#$(if $(filter codec_ilbc,$(EMBEDDED_MODS)),modules.link,codec_ilbc.so): $(LIBILBC)
 
 $(if $(filter codec_g722,$(EMBEDDED_MODS)),modules.link,codec_g722.so): g722/g722_encode.o g722/g722_decode.o
 g722/g722_encode.o g722/g722_decode.o: _ASTCFLAGS+=$(call MOD_ASTCFLAGS,codec_g722)
diff --git a/codecs/codec_ilbc.c b/codecs/codec_ilbc.c
index 11c1712..7886ec1 100644
--- a/codecs/codec_ilbc.c
+++ b/codecs/codec_ilbc.c
@@ -37,8 +37,20 @@ ASTERISK_FILE_VERSION(__FILE__, "$Revision$")
 #include "asterisk/module.h"
 #include "asterisk/utils.h"
 
+#define ILBC_EXTERNAL
+
+#ifdef ILBC_EXTERNAL
+#include <ilbc.h>
+typedef WebRtc_UWord16 ilbc_bytes;
+typedef WebRtc_Word16  ilbc_block;
+#define BUF_TYPE i16
+#else
 #include "ilbc/iLBC_encode.h"
 #include "ilbc/iLBC_decode.h"
+typedef unsigned char ilbc_bytes;
+typedef float         ilbc_block;
+#define BUF_TYPE uc
+#endif
 
 #define USE_ILBC_ENHANCER	0
 #define ILBC_MS 			30
@@ -86,7 +98,7 @@ static int ilbctolin_framein(struct ast_trans_pvt *pvt, struct ast_frame *f)
 	   the tail location.  Read in as many frames as there are */
 	int x,i;
 	int16_t *dst = pvt->outbuf.i16;
-	float tmpf[ILBC_SAMPLES];
+	ilbc_block tmpf[ILBC_SAMPLES];
 
 	if (!f->data.ptr && f->datalen) {
 		ast_debug(1, "issue 16070, ILIB ERROR. data = NULL datalen = %d src = %s\n", f->datalen, f->src ? f->src : "no src set");
@@ -144,13 +156,13 @@ static struct ast_frame *lintoilbc_frameout(struct ast_trans_pvt *pvt)
 	if (pvt->samples < ILBC_SAMPLES)
 		return NULL;
 	while (pvt->samples >= ILBC_SAMPLES) {
-		float tmpf[ILBC_SAMPLES];
+		ilbc_block tmpf[ILBC_SAMPLES];
 		int i;
 
 		/* Encode a frame of data */
 		for (i = 0 ; i < ILBC_SAMPLES ; i++)
 			tmpf[i] = tmp->buf[samples + i];
-		iLBC_encode( pvt->outbuf.uc + datalen, tmpf, &tmp->enc);
+		iLBC_encode( (ilbc_bytes*)pvt->outbuf.BUF_TYPE + datalen, tmpf, &tmp->enc);
 
 		datalen += ILBC_FRAME_LEN;
 		samples += ILBC_SAMPLES;
